==> mural-0.0.4.tar.gz: mural-0.0.4/setup.py <==
import setuptools

setuptools.setup(
    name="mural",
    version="0.0.4",
    author="William Wyatt",
    author_email="wwyatt@ucsc.edu",
    description="Market game",
    long_description="Market Game.",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    url="https://github.com/Tsangares/market",
    include_package_data=True,
    scripts=[
        'mural/bin/business',
        'mural/bin/market',
        'mural/bin/mine',
        'mural/bin/transact',
        'mural/bin/update',
        'mural/bin/oracle',
        'mural/bin/convoy',
        'mural/bin/setAccount',
        'mural/bin/net'
    ],
    install_requires=[
        "requests==2.22.0",
	"aniso8601==7.0.0",
	"bleach==3.1.0",
	"certifi==2019.6.16",
	"chardet==3.0.4",
	"Click==7.0",
	"dnspython==1.16.0",
	"docutils==0.14",
	"Flask==1.0.3",
	"Flask-PyMongo==2.3.0",
	"Flask-RESTful==0.3.7",
	"Flask-SocketIO==4.1.0",
	"idna==2.8",
	"itsdangerous==1.1.0",
	"Jinja2==2.10.1",
	"jsonify==0.5",
	"MarkupSafe==1.1.1",
	"numpy==1.16.4",
	"pkginfo==1.5.0.1",
	"prompt-toolkit==1.0.14",
	"Pygments==2.4.2",
	"PyInquirer==1.0.3",
	"pymongo==3.8.0",
	"python-engineio==3.8.2.post1",
	"python-socketio==4.2.0",
	"pytz==2019.1",
	"PyYAML==5.1.1",
	"readme-renderer==24.0",
	"regex==2019.6.8",
	"requests-toolbelt==0.9.1",
	"six==1.12.0",
	"tqdm==4.32.2",
	"twine==1.13.0",
	"urllib3==1.25.3",
	"wcwidth==0.1.7",
	"webencodings==0.5.1",
	"Werkzeug==0.15.4",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)

==> mural-0.0.5.tar.gz: mural-0.0.5/setup.py <==
import setuptools

setuptools.setup(
    name="mural",
    version="0.0.5",
    author="William Wyatt",
    author_email="wwyatt@ucsc.edu",
    description="Market game",
    long_description="Market Game.",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    url="https://github.com/Tsangares/market",
    include_package_data=True,
    scripts=[
        'mural/bin/business',
        'mural/bin/market',
        'mural/bin/mine',
        'mural/bin/transact',
        'mural/bin/update',
        'mural/bin/oracle',
        'mural/bin/convoy',
        'mural/bin/setAccount',
        'mural/bin/net'
    ],
    install_requires=[
        "requests==2.22.0",
	"aniso8601==7.0.0",
	"bleach==3.1.0",
	"certifi==2019.6.16",
	"chardet==3.0.4",
	"Click==7.0",
	"dnspython==1.16.0",
	"docutils==0.14",
	"Flask==1.0.3",
	"Flask-PyMongo==2.3.0",
	"Flask-RESTful==0.3.7",
	"Flask-SocketIO==4.1.0",
	"idna==2.8",
	"itsdangerous==1.1.0",
	"Jinja2==2.10.1",
	"jsonify==0.5",
	"MarkupSafe==1.1.1",
	"numpy==1.16.4",
	"pkginfo==1.5.0.1",
	"prompt-toolkit>=1.0.14",
	"Pygments==2.4.2",
	"PyInquirer>=1.0.3",
	"pymongo==3.8.0",
	"python-engineio==3.8.2.post1",
	"python-socketio==4.2.0",
	"pytz==2019.1",
	"PyYAML==5.1.1",
	"readme-renderer==24.0",
	"regex==2019.6.8",
	"requests-toolbelt==0.9.1",
	"six==1.12.0",
	"tqdm==4.32.2",
	"twine==1.13.0",
	"urllib3==1.25.3",
	"wcwidth==0.1.7",
	"webencodings==0.5.1",
	"Werkzeug==0.15.4",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
